abacusai.algorithm — AbacusAI documentation

# abacusai.algorithm

## Classes

`Algorithm` | Customer created algorithm

## Module Contents

class abacusai.algorithm.Algorithm(client, name=None, problemType=None, createdAt=None, updatedAt=None, isDefaultEnabled=None, trainingInputMappings=None, trainFunctionName=None, predictFunctionName=None, predictManyFunctionName=None, initializeFunctionName=None, configOptions=None, algorithmId=None, useGpu=None, algorithmTrainingConfig=None, onlyOfflineDeployable=None, codeSource={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Customer created algorithm

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name of the algorithm

    - problemType (str) – The type of the problem this algorithm will work on

    - createdAt (str) – When the algorithm was created

    - updatedAt (str) – When the algorithm was last updated

    - isDefaultEnabled (bool) – Whether train with the algorithm by default

    - trainingInputMappings (dict) – The mappings for train function parameters’ names, e.g. names for training data, name for training config

    - trainFunctionName (str) – Name of the function found in the source code that will be executed to train the model. It is not executed when this function is run.

    - predictFunctionName (str) – Name of the function found in the source code that will be executed run predictions through model. It is not executed when this function is run.

    - predictManyFunctionName (str) – Name of the function found in the source code that will be executed for batch prediction of the model. It is not executed when this function is run.

    - initializeFunctionName (str) – Name of the function found in the source code to initialize the trained model before using it to make predictions using the model

    - configOptions (dict) – Map dataset types and configs to train function parameter names

    - algorithmId (str) – The unique identifier of the algorithm

    - useGpu (bool) – Whether to use gpu for model training

    - algorithmTrainingConfig (dict) – The algorithm specific training config

    - onlyOfflineDeployable (bool) – Whether or not the algorithm is only allowed to be deployed offline

    - codeSource (CodeSource) – Info about the source code of the algorithm

  name = None
  problem_type = None
  created_at = None
  updated_at = None
  is_default_enabled = None
  training_input_mappings = None
  train_function_name = None
  predict_function_name = None
  predict_many_function_name = None
  initialize_function_name = None
  config_options = None
  algorithm_id = None
  use_gpu = None
  algorithm_training_config = None
  only_offline_deployable = None
  code_source
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict